@@ -2,7 +2,7 @@
    rcfile.c
 
    This file is part of GNU Anubis.
-   Copyright (C) 2001-2014 The Anubis Team.
+   Copyright (C) 2001-2020 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -260,6 +260,7 @@ process_rcfile (int method)
 #define KW_LOG_FACILITY             35
 #define KW_LOG_TAG                  36
 #define KW_ESMTP_AUTH_DELAYED       37
+#define KW_USE_PAM                  38
 
 char **
 list_to_argv (ANUBIS_LIST  list)
@@ -328,22 +329,6 @@ static volatile unsigned long _anubis_hang;
 /* List of users who are allowed to use HANG in their profiles */
 ANUBIS_LIST allow_hang_users; 
 
-static struct rc_kwdef esmtp_kw[] = {
-  { "esmtp-auth",   KW_ESMTP_AUTH, KWF_HIDDEN },
-  { "esmtp-anonymous-token", KW_ESMTP_ANONYMOUS_TOKEN, KWF_HIDDEN },
-  { "esmtp-auth-id", KW_ESMTP_AUTH_ID, KWF_HIDDEN },
-  { "esmtp-authz-id", KW_ESMTP_AUTHZ_ID, KWF_HIDDEN },
-  { "esmtp-password", KW_ESMTP_PASSWORD, KWF_HIDDEN },
-  { "esmtp-service",  KW_ESMTP_SERVICE, KWF_HIDDEN },
-  { "esmtp-hostname", KW_ESMTP_HOSTNAME, KWF_HIDDEN },
-  { "esmtp-generic-service", KW_ESMTP_SERVICE, KWF_HIDDEN },
-  { "esmtp-passcode", KW_ESMTP_PASSCODE, KWF_HIDDEN },
-  { "esmtp-realm", KW_ESMTP_REALM, KWF_HIDDEN },
-  { "esmtp-allowed-mech", KW_ESMTP_ALLOWED_MECH },
-  { "esmtp-require-encryption", KW_ESMTP_REQUIRE_ENCRYPTION },
-  { NULL }
-};
-
 static int
 parse_esmtp_kv (int key, ANUBIS_LIST arglist)
 {
@@ -545,7 +530,7 @@ control_parser (EVAL_ENV env, int key, ANUBIS_LIST arglist, void *inv_data)
       
     case KW_LOCAL_MTA:
       xfree (session.execpath);
-      argcv_free (-1, session.execargs);
+      argv_free (session.execargs);
       session.execpath = strdup (arg);
       session.execargs = list_to_argv (arglist);
       topt |= T_LOCAL_MTA;
@@ -658,6 +643,16 @@ control_parser (EVAL_ENV env, int key, ANUBIS_LIST arglist, void *inv_data)
       setbool (env, arg, topt, T_ESMTP_AUTH_DELAYED);
       break;
 #endif
+
+    case KW_USE_PAM:
+      setbool (env, arg, use_pam, 1);
+#if !defined(HAVE_PAM)
+      if (use_pam)
+	eval_error (0, env,
+		    _("statement ignored: anubis compiled without PAM support"));
+#endif
+      break;
+
     default:
       if (parse_esmtp_kv (key, arglist))
 	eval_error (2, env,
@@ -678,6 +673,7 @@ static struct rc_kwdef init_kw[] = {
   { "log-facility", KW_LOG_FACILITY },
   { "log-tag", KW_LOG_TAG },
   { "ALLOW-HANG",   KW_ALLOW_HANG },
+  { "use-pam", KW_USE_PAM },
   { NULL },
 };
 
@@ -881,7 +877,7 @@ rule_parser (EVAL_ENV env, int key, ANUBIS_LIST arglist, void *inv_data)
     case KW_EXTERNAL_BODY_PROCESSOR:
       argv = list_to_argv (arglist);
       message_external_proc (msg, argv);
-      argcv_free (-1, argv);
+      argv_free (argv);
       break;
       
     default:
@@ -950,7 +946,7 @@ smtp_rule_parser (EVAL_ENV env, int key, ANUBIS_LIST arglist, void *inv_data)
     case KW_EXTERNAL_BODY_PROCESSOR:
       argv = list_to_argv (arglist);
       message_external_proc (msg, argv);
-      argcv_free (-1, argv);
+      argv_free (argv);
       break;
       
     default:
