@@ -2,8 +2,7 @@
    tunnel.c
 
    This file is part of GNU Anubis.
-   Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007, 2008,
-   2009, 2010, 2011 The Anubis Team.
+   Copyright (C) 2001-2020 The Anubis Team.
 
    GNU Anubis is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -41,8 +40,6 @@ get_ehlo_domain (void)
 {
   return smtp_ehlo_domain_name ? smtp_ehlo_domain_name : get_localname ();
 }
-
-
 
 
 /* Collect and send headers */
@@ -503,9 +500,7 @@ handle_starttls (char *command)
 	}
       smtp_reply_free (reply);
 
-      stream = start_ssl_client (remote_server,
-				 secure.cafile,
-				 options.termlevel > NORMAL);
+      stream = start_ssl_client (remote_server, options.termlevel > NORMAL);
       if (!stream)
 	return 0;
       remote_server = stream;
@@ -543,10 +538,7 @@ handle_starttls (char *command)
     check_filemode (secure.key);
 
   swrite (SERVER, remote_client, "220 2.0.0 Ready to start TLS" CRLF);
-  stream = start_ssl_server (remote_client,
-			     secure.cafile,
-			     secure.cert,
-			     secure.key, options.termlevel > NORMAL);
+  stream = start_ssl_server (remote_client, options.termlevel > NORMAL);
   if (!stream)
     {
       swrite (SERVER, remote_client, "454 4.3.3 TLS not available" CRLF);
@@ -646,9 +638,7 @@ handle_ehlo (ANUBIS_SMTP_REPLY reply)
 	}
       smtp_reply_free (newreply);
 
-      stream = start_ssl_client (remote_server,
-				 secure.cafile,
-				 options.termlevel > NORMAL);
+      stream = start_ssl_client (remote_server, options.termlevel > NORMAL);
       if (!stream)
 	{
 	  topt &= ~T_SSL_ONEWAY;
